import sys
import beniutils as b
import beniutils.task as bt


moduleName = None
parDict = {}

if sys.executable.endswith("python.exe"):
    workspacePath = b.getPath("./../../workspace")
    import main_config
    moduleName = main_config.moduleName
    parDict = main_config.parDict
else:
    workspacePath = b.getPath("./workspace")

bt.init(workspacePath)
bt.runMain(moduleName, **parDict)
